@@ -1,4 +1,4 @@
-from .encryption import generate_key, key_encrypt, password_encrypt, password_decrypt, key_decrypt
+from .encryption import generate_key, key_encrypt, key_decrypt, password_encrypt, password_decrypt
 from .generation import generate_password, generate_urlsafe_password
 
 __all__ = [
